==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/VpcIpamOperatingRegionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.VpcIpamOperatingRegionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property regionName The name of the Region you want to add to the IPAM.
 */
public data class VpcIpamOperatingRegionArgs(
    public val regionName: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.VpcIpamOperatingRegionArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.VpcIpamOperatingRegionArgs =
        com.pulumi.aws.ec2.inputs.VpcIpamOperatingRegionArgs.builder()
            .regionName(regionName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VpcIpamOperatingRegionArgs].
 */
@PulumiTagMarker
public class VpcIpamOperatingRegionArgsBuilder internal constructor() {
    private var regionName: Output<String>? = null

    /**
     * @param value The name of the Region you want to add to the IPAM.
     */
    @JvmName("bkqwmhkefkyoapkr")
    public suspend fun regionName(`value`: Output<String>) {
        this.regionName = value
    }

    /**
     * @param value The name of the Region you want to add to the IPAM.
     */
    @JvmName("ordfawomhevinjro")
    public suspend fun regionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regionName = mapped
    }

    internal fun build(): VpcIpamOperatingRegionArgs = VpcIpamOperatingRegionArgs(
        regionName = regionName ?: throw PulumiNullFieldException("regionName"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/ec2/kotlin/inputs/VpcIpamOperatingRegionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.ec2.kotlin.inputs

import com.pulumi.aws.ec2.inputs.VpcIpamOperatingRegionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property regionName The name of the Region you want to add to the IPAM.
 */
public data class VpcIpamOperatingRegionArgs(
    public val regionName: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.ec2.inputs.VpcIpamOperatingRegionArgs> {
    override fun toJava(): com.pulumi.aws.ec2.inputs.VpcIpamOperatingRegionArgs =
        com.pulumi.aws.ec2.inputs.VpcIpamOperatingRegionArgs.builder()
            .regionName(regionName.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VpcIpamOperatingRegionArgs].
 */
@PulumiTagMarker
public class VpcIpamOperatingRegionArgsBuilder internal constructor() {
    private var regionName: Output<String>? = null

    /**
     * @param value The name of the Region you want to add to the IPAM.
     */
    @JvmName("eytajrwjxcacxwbw")
    public suspend fun regionName(`value`: Output<String>) {
        this.regionName = value
    }

    /**
     * @param value The name of the Region you want to add to the IPAM.
     */
    @JvmName("uxlalhdxsjkwxpqp")
    public suspend fun regionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.regionName = mapped
    }

    internal fun build(): VpcIpamOperatingRegionArgs = VpcIpamOperatingRegionArgs(
        regionName = regionName ?: throw PulumiNullFieldException("regionName"),
    )
}
